==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/add_desktops_volumes_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddDesktopsVolumesReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'desktop_type': 'str',
        'desktop_volumes': 'list[AddDesktopVolumesReq]'
    }

    attribute_map = {
        'desktop_type': 'desktop_type',
        'desktop_volumes': 'desktop_volumes'
    }

    def __init__(self, desktop_type=None, desktop_volumes=None):
        """AddDesktopsVolumesReq

        The model defined in huaweicloud sdk

        :param desktop_type: 桌面类别  - DESKTOP：普通桌面。 - RENDER_DESKTOP：渲染桌面。
        :type desktop_type: str
        :param desktop_volumes: 新增磁盘参数。
        :type desktop_volumes: list[:class:`huaweicloudsdkworkspace.v2.AddDesktopVolumesReq`]
        """
        
        

        self._desktop_type = None
        self._desktop_volumes = None
        self.discriminator = None

        if desktop_type is not None:
            self.desktop_type = desktop_type
        if desktop_volumes is not None:
            self.desktop_volumes = desktop_volumes

    @property
    def desktop_type(self):
        """Gets the desktop_type of this AddDesktopsVolumesReq.

        桌面类别  - DESKTOP：普通桌面。 - RENDER_DESKTOP：渲染桌面。

        :return: The desktop_type of this AddDesktopsVolumesReq.
        :rtype: str
        """
        return self._desktop_type

    @desktop_type.setter
    def desktop_type(self, desktop_type):
        """Sets the desktop_type of this AddDesktopsVolumesReq.

        桌面类别  - DESKTOP：普通桌面。 - RENDER_DESKTOP：渲染桌面。

        :param desktop_type: The desktop_type of this AddDesktopsVolumesReq.
        :type desktop_type: str
        """
        self._desktop_type = desktop_type

    @property
    def desktop_volumes(self):
        """Gets the desktop_volumes of this AddDesktopsVolumesReq.

        新增磁盘参数。

        :return: The desktop_volumes of this AddDesktopsVolumesReq.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.AddDesktopVolumesReq`]
        """
        return self._desktop_volumes

    @desktop_volumes.setter
    def desktop_volumes(self, desktop_volumes):
        """Sets the desktop_volumes of this AddDesktopsVolumesReq.

        新增磁盘参数。

        :param desktop_volumes: The desktop_volumes of this AddDesktopsVolumesReq.
        :type desktop_volumes: list[:class:`huaweicloudsdkworkspace.v2.AddDesktopVolumesReq`]
        """
        self._desktop_volumes = desktop_volumes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddDesktopsVolumesReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/add_desktops_volumes_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddDesktopsVolumesReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'desktop_type': 'str',
        'desktop_volumes': 'list[AddDesktopVolumesReq]'
    }

    attribute_map = {
        'desktop_type': 'desktop_type',
        'desktop_volumes': 'desktop_volumes'
    }

    def __init__(self, desktop_type=None, desktop_volumes=None):
        r"""AddDesktopsVolumesReq

        The model defined in huaweicloud sdk

        :param desktop_type: 桌面类别  - DESKTOP：普通桌面。 - RENDER_DESKTOP：渲染桌面。
        :type desktop_type: str
        :param desktop_volumes: 新增磁盘参数。
        :type desktop_volumes: list[:class:`huaweicloudsdkworkspace.v2.AddDesktopVolumesReq`]
        """
        
        

        self._desktop_type = None
        self._desktop_volumes = None
        self.discriminator = None

        if desktop_type is not None:
            self.desktop_type = desktop_type
        if desktop_volumes is not None:
            self.desktop_volumes = desktop_volumes

    @property
    def desktop_type(self):
        r"""Gets the desktop_type of this AddDesktopsVolumesReq.

        桌面类别  - DESKTOP：普通桌面。 - RENDER_DESKTOP：渲染桌面。

        :return: The desktop_type of this AddDesktopsVolumesReq.
        :rtype: str
        """
        return self._desktop_type

    @desktop_type.setter
    def desktop_type(self, desktop_type):
        r"""Sets the desktop_type of this AddDesktopsVolumesReq.

        桌面类别  - DESKTOP：普通桌面。 - RENDER_DESKTOP：渲染桌面。

        :param desktop_type: The desktop_type of this AddDesktopsVolumesReq.
        :type desktop_type: str
        """
        self._desktop_type = desktop_type

    @property
    def desktop_volumes(self):
        r"""Gets the desktop_volumes of this AddDesktopsVolumesReq.

        新增磁盘参数。

        :return: The desktop_volumes of this AddDesktopsVolumesReq.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.AddDesktopVolumesReq`]
        """
        return self._desktop_volumes

    @desktop_volumes.setter
    def desktop_volumes(self, desktop_volumes):
        r"""Sets the desktop_volumes of this AddDesktopsVolumesReq.

        新增磁盘参数。

        :param desktop_volumes: The desktop_volumes of this AddDesktopsVolumesReq.
        :type desktop_volumes: list[:class:`huaweicloudsdkworkspace.v2.AddDesktopVolumesReq`]
        """
        self._desktop_volumes = desktop_volumes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddDesktopsVolumesReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
